summaryrefslogtreecommitdiff
path: root/gdb/c-valprint.c
diff options
context:
space:
mode:
authorTom Tromey <tom@tromey.com>2022-01-22 16:32:48 -0700
committerTom Tromey <tom@tromey.com>2022-02-14 06:22:33 -0700
commit660da3c14b3b1815d6b3f1849a7225a10d819042 (patch)
tree569508305b97cfb486866c69a09fa3635e9cd213 /gdb/c-valprint.c
parent362501dc5c85ae67c7141292ed5be1bfbd334645 (diff)
downloadbinutils-gdb-660da3c14b3b1815d6b3f1849a7225a10d819042.tar.gz
Remove LA_PRINT_STRING
This removes the LA_PRINT_STRING macro, in favor of using ordinary method calls.
Diffstat (limited to 'gdb/c-valprint.c')
-rw-r--r--gdb/c-valprint.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/gdb/c-valprint.c b/gdb/c-valprint.c
index 047e5687b0a..0d30700c06d 100644
--- a/gdb/c-valprint.c
+++ b/gdb/c-valprint.c
@@ -277,7 +277,7 @@ c_value_print_array (struct value *val,
++temp_len)
;
/* Force LA_PRINT_STRING to print ellipses if
we've printed the maximum characters and
the next character is not \000. */
if (temp_len == options->print_max && temp_len < len)
@@ -292,8 +292,8 @@ c_value_print_array (struct value *val,
len = temp_len;
}
- LA_PRINT_STRING (stream, unresolved_elttype, valaddr, len,
- NULL, force_ellipses, options);
+ current_language->printstr (stream, unresolved_elttype, valaddr, len,
+ NULL, force_ellipses, options);
}
else
{
@@ -277,7 +277,7 @@ c_value_print_array (struct value *val,
;
- /* Force LA_PRINT_STRING to print ellipses if
+ /* Force printstr to print ellipses if
we've printed the maximum characters and
the next character is not \000. */